@@ -14,8 +14,8 @@ NULL
 ##' This class defines parameters of a Gaussian Mixture Model. Inherits the [\code{\linkS4class{Parameter}}] class.
 ##' 
 ##' \describe{
-##'   \item{mean}{a numeric vector containing mean of each cluster.}
-##'   \item{variance}{a vector of matrix containing variance matrix of each cluster.}
+##'   \item{mean}{a matrix containing mean of each cluster.}
+##'   \item{variance}{a list of matrices containing variance matrix of each cluster.}
 ##' }
 ##'
 ##' @examples
@@ -30,11 +30,11 @@ NULL
 setClass(
     Class="GaussianParameter",
     representation=representation(
-        mean = "numeric",
+        mean = "matrix",
         variance = "list"
     ),
     prototype=prototype(
-        mean = numeric(0),
+        mean = matrix(0),
         variance = list(0)
     ),
     contains=c("Parameter")
